@@ -3,5 +3,5 @@
 set -e
 
 python3 setup.py sdist bdist_wheel
-twine check dist/*
-twine upload dist/*
+python3 -m twine check dist/*
+python3 -m twine upload dist/*
